Aerosol2D
=========

.. currentmodule:: aerosoltools.aerosol2d

.. autoclass:: Aerosol2D
   :noindex:

Properties
----------

.. autosummary::
   :toctree: _autosummary
   :nosignatures:

   Aerosol2D.activities
   Aerosol2D.activity_periods
   Aerosol2D.bin_edges
   Aerosol2D.bin_mids
   Aerosol2D.data
   Aerosol2D.density
   Aerosol2D.dtype
   Aerosol2D.extra_data
   Aerosol2D.instrument
   Aerosol2D.metadata
   Aerosol2D.original_data
   Aerosol2D.serial_number
   Aerosol2D.size_data
   Aerosol2D.time
   Aerosol2D.total_concentration
   Aerosol2D.unit

Methods
-------

.. autosummary::
   :toctree: _autosummary
   :nosignatures:

   Aerosol2D.convert_to_mass_concentration
   Aerosol2D.convert_to_number_concentration
   Aerosol2D.convert_to_surface_concentration
   Aerosol2D.convert_to_volume_concentration
   Aerosol2D.copy_self
   Aerosol2D.correct_diffusion_losses
   Aerosol2D.get_activity_data
   Aerosol2D.mark_activities
   Aerosol2D.normalize_logdp
   Aerosol2D.plot_psd
   Aerosol2D.plot_timeseries
   Aerosol2D.plot_total_conc
   Aerosol2D.set_density
   Aerosol2D.summarize
   Aerosol2D.timecrop
   Aerosol2D.timerebin
   Aerosol2D.timeshift
   Aerosol2D.timesmooth
   Aerosol2D.unnormalize_logdp
